@@ -3,11 +3,12 @@ import numpy as np
 import scipy
 from scipy.sparse import csr_matrix
 from gpuinfo import GPUInfo as g
-import gpuadder
+#import gpuadder - that was our cuda package, which is important in this 
+#     in this file, because that here is the "save version", not the opencl-only version
 import time
-import collapse
+#import collapse
 
-from pynvml import *
+#from pynvml import * - hopefully we can comment that out, I have no idea, what that is
 
 import os
 os.environ['PYOPENCL_COMPILER_OUTPUT'] = '0'
@@ -555,7 +556,7 @@ def levenshtein_cl(strings1, strings2, ascii_total1, ascii_total2, max_len, gpu_
     """
 
     # TODO: discard the diagonal terms
-
+    """
     nvmlInit()
     for i in range(nvmlDeviceGetCount()):
         handle = nvmlDeviceGetHandleByIndex(i)
@@ -564,6 +565,7 @@ def levenshtein_cl(strings1, strings2, ascii_total1, ascii_total2, max_len, gpu_
             nvmlDeviceGetName(handle),
             meminfo.free/1024.**2, meminfo.used/1024.**2, meminfo.total/1024.**2))
     nvmlShutdown()
+    """
 
     print("\n len(strings1): ", len(strings1))
 
